spacr.gui_core — spacr 0.5.0 documentation

# spacr.gui_core

## Module Contents

spacr.gui_core.q = None

spacr.gui_core.console_output = None

spacr.gui_core.parent_frame = None

spacr.gui_core.vars_dict = None

spacr.gui_core.canvas = None

spacr.gui_core.canvas_widget = None

spacr.gui_core.scrollable_frame = None

spacr.gui_core.progress_label = None

spacr.gui_core.fig_queue = None

spacr.gui_core.figures = None

spacr.gui_core.figure_index = None

spacr.gui_core.progress_bar = None

spacr.gui_core.usage_bars = None

spacr.gui_core.index_control = None

spacr.gui_core.thread_control

spacr.gui_core.toggle_settings(button_scrollable_frame)

spacr.gui_core.display_figure(fig)

spacr.gui_core.clear_unused_figures()

spacr.gui_core.show_previous_figure()

spacr.gui_core.show_next_figure()

spacr.gui_core.process_fig_queue()

spacr.gui_core.update_figure(value)

spacr.gui_core.setup_plot_section(vertical_container, settings_type)

spacr.gui_core.set_globals(thread_control_var, q_var, console_output_var, parent_frame_var, vars_dict_var, canvas_var, canvas_widget_var, scrollable_frame_var, fig_queue_var, progress_bar_var, usage_bars_var)

spacr.gui_core.import_settings(settings_type='mask')

spacr.gui_core.setup_settings_panel(vertical_container, settings_type='mask')

spacr.gui_core.setup_console(vertical_container)

spacr.gui_core.setup_button_section(horizontal_container, settings_type='mask', run=True, abort=True, download=True, import_btn=True)

spacr.gui_core.setup_usage_panel(horizontal_container, btn_col, uppdate_frequency)

spacr.gui_core.initiate_abort()

spacr.gui_core.check_src_folders_files(settings, settings_type, q)

  Checks if ‘src’ is a key in the settings dictionary and if it exists as a valid path. If ‘src’ is a list, iterates through the list and checks each path. If any path is missing, prompts the user to edit or remove invalid paths.

spacr.gui_core.start_process(q=None, fig_queue=None, settings_type='mask')

spacr.gui_core.process_console_queue()

spacr.gui_core.process_console_queue_v2()

spacr.gui_core.main_thread_update_function(root, q, fig_queue, canvas_widget)

spacr.gui_core.cleanup_previous_instance()

  Cleans up resources from the previous application instance.

spacr.gui_core.initiate_root(parent, settings_type='mask')

  Initializes the root window and sets up the GUI components based on the specified settings type.

  Parameters:

    - parent (tkinter.Tk or tkinter.Toplevel) – The parent window for the GUI.

    - settings_type (str, optional) – The type of settings to be displayed in the GUI. Defaults to ‘mask’.

  Returns:

    A tuple containing the parent frame and the dictionary of variables used in the GUI.

  Return type:

    tuple